@@ -8,7 +8,11 @@ from .messages.format import message_format
 from .messages.tool_call import has_tool_calling, parse_tool_calling
 from .models.chat_model import load_chat_model, register_model_provider
 from .models.embbedings import load_embeddings, register_embeddings_provider
-from .tools.interrupt import human_in_the_loop
+from .tools.interrupt import (
+    human_in_the_loop,
+    human_in_the_loop_async,
+    InterrruptParams,
+)
 
 __all__ = [
     "has_tool_calling",
@@ -23,7 +27,9 @@ __all__ = [
     "load_chat_model",
     "register_model_provider",
     "human_in_the_loop",
+    "human_in_the_loop_async",
+    "InterrruptParams",
 ]
 
 
-__version__ = "0.1.4"
+__version__ = "0.1.5"
